@@ -27,7 +27,7 @@ class LanguageIndependentFieldsManager(object):
     def __init__(self, context):
         self.context = context
 
-    def copy_fields(self, translation):
+    def has_independent_fields(self):
         fti = getUtility(IDexterityFTI, name=self.context.portal_type)
         schemas = []
         schemas.append(fti.lookupSchema())
@@ -41,6 +41,26 @@ class LanguageIndependentFieldsManager(object):
         for schema in schemas:
             for field_name in schema:
                 if ILanguageIndependentField.providedBy(schema[field_name]):
+                    return True
+        return False
+
+    def copy_fields(self, translation):
+        fti = getUtility(IDexterityFTI, name=self.context.portal_type)
+        schemas = []
+        schemas.append(fti.lookupSchema())
+
+        for behavior_schema in \
+                utils.getAdditionalSchemata(self.context,
+                                            self.context.portal_type):
+            if behavior_schema is not None:
+                schemas.append(behavior_schema)
+
+        doomed = False
+        for schema in schemas:
+            for field_name in schema:
+                if ILanguageIndependentField.providedBy(schema[field_name]):
+                    doomed = True
+
                     value = getattr(schema(self.context), field_name, _marker)
                     if IRelationValue.providedBy(value):
                         obj = value.to_object
@@ -54,3 +74,8 @@ class LanguageIndependentFieldsManager(object):
                         # We check if not (value == _marker) because
                         # z3c.relationfield has an __eq__
                         setattr(schema(translation), field_name, value)
+
+        # If at least one field has been copied over to the translation
+        # we need to inform subscriber to trigger an ObjectModifiedEvent
+        # on that translation.
+        return doomed
